Index: bp-core-update.php
===================================================================
--- bp-core-update.php	(revision 5976)
+++ bp-core-update.php	(working copy)
@@ -517,7 +517,7 @@
 	function step_theme() {
 
 		$installed_plugins = get_plugins();
-		$installed_themes  = get_themes();
+		$installed_themes  = wp_get_themes();
 		$bp_themes         = array();
 
 		$template_pack_installed = false;
@@ -539,9 +539,9 @@
 		}
 
 		// Get theme screenshot
-		$current_theme = get_current_theme();
+		$current_theme = wp_get_theme();
 		$screenshot    = '';
-		$themes        = get_themes();
+		$themes        = wp_get_theme();
 
 		if ( !empty( $themes[$current_theme]['Screenshot'] ) ) {
 			$screenshot = trailingslashit( get_stylesheet_directory_uri() ) . $themes[$current_theme]['Screenshot'];

Index: bp-core-functions.php
===================================================================
--- bp-core-functions.php	(revision 5976)
+++ bp-core-functions.php	(working copy)
@@ -238,8 +238,8 @@
 	 * Are you using a BP-compatible theme?
 	 */
 
-	// Get current theme info
-	$ct = current_theme_info();
+	// Get current theme info via wp_get_theme()
+	$ct = wp_get_theme(); //current_theme_info(); 
 
 	// The best way to remove this notice is to add a "buddypress" tag to
 	// your active theme's CSS header.